@@ -9,7 +9,7 @@ from src import settings
 from src.graphql import GraphQL
 from src.helpers import check_running_cluster
 from src.local.providers.types import K8sProviderType
-from src.local.system import KubeAPI, Telepresence
+from src.local.system import Docker, KubeAPI, Telepresence
 
 
 @click.command()
@@ -20,6 +20,8 @@ def list(ctx, organization, **kwargs):
     Display a table of all available project names alongside with the ids.
     """
 
+    _ = ctx.auth.refresh()
+
     # context
     organization_id, _, _ = ctx.context.get_context_ids_from_arguments(organization_argument=organization)
 
@@ -68,6 +70,8 @@ def info(ctx, project=None, organization=None, **kwargs):
     Displays the id, title and optional description of the selected project.
     """
 
+    _ = ctx.auth.refresh()
+
     # context
     organization_id, project_id, _ = ctx.context.get_context_ids_from_arguments(
         organization_argument=organization, project_argument=project
@@ -144,6 +148,11 @@ def up(ctx, project=None, organization=None, ingress=None, provider=None, worker
 
     """
 
+    _ = ctx.auth.refresh()
+
+    if not Docker().daemon_active():
+        console.error("Docker is not running. Please start Docker before starting a project.", _exit=True)
+
     # context
     organization_id, project_id, _ = ctx.context.get_context_ids_from_arguments(
         organization_argument=organization, project_argument=project
@@ -155,12 +164,12 @@ def up(ctx, project=None, organization=None, ingress=None, provider=None, worker
 
     # argument
     if not project_id:
-        project_id = console.project_list(ctx, organization_id=organization_id, exclude=cluster_id_list)
+        project_id = console.project_list(ctx, organization_id=organization_id, excludes=cluster_id_list)
         if not project_id:
             return None
 
     if project_id in cluster_id_list:
-        console.info(f"Project '{project}' is already up.", _exit=True)
+        console.info(f"Project '{project_id}' is already up.", _exit=True)
 
     # GraphQL
     try:
@@ -374,3 +383,59 @@ def delete(ctx, project=None, organization=None, **kwargs):
         ctx.cluster_manager.delete(cluster.id)
     else:
         console.error("The cluster could not be deleted.")
+
+
+@click.command()
+@click.pass_obj
+def prune(ctx, **kwargs):
+    """
+    Remove unused clusters.
+    """
+
+    # GraphQL
+    try:
+        graph_ql = GraphQL(authentication=ctx.auth)
+        data = graph_ql.query(
+            """
+            query {
+                allProjects {
+                    results {
+                        id
+                    }
+                }
+            }
+            """
+        )
+        projects = data["allProjects"]["results"]
+    except Exception as e:
+        console.debug(e)
+        console.exit_generic_error()
+
+    # cluster
+    cluster_list = ctx.cluster_manager.get_cluster_list()
+
+    # select clusters to prune
+    prune_clusters = []
+    for cluster_data in cluster_list:
+        if cluster_data.id not in [project["id"] for project in projects]:
+            prune_clusters.append(cluster_data)
+
+    for cluster_data in prune_clusters:
+        console.info(f"It seems like the project for cluster '{cluster_data.name}' has been deleted.")
+
+        # confirm question
+        confirmed = console.confirm(question="Do want to remove the cluster? [N/y]: ")
+        if not confirmed:
+            console.info("No action taken.")
+            continue
+
+        # delete
+        try:
+            cluster = ctx.cluster_manager.select(cluster_data=cluster_data)
+            success = cluster.delete()
+            if success:
+                console.success("The project was deleted successfully.")
+                ctx.cluster_manager.delete(cluster.id)
+        except Exception as e:
+            console.debug(e)
+            console.error("The cluster could not be deleted.")
